Clojure only.

idem.dispatcher

Outbox Dispatcher (Relay). Responsible for polling pending events and publishing them via a Publisher.

Outbox Dispatcher (Relay).
Responsible for polling pending events and publishing them via a Publisher.
raw docstring

start!clj

(start! ds publisher & [opts])

Starts the Dispatcher background loop.

Parameters: ds - Database DataSource (used to create the default Postgres store). publisher - An implementation of idem.protocol/Publisher. opts - Configuration map (optional): :poll-interval-ms Polling interval (default 1000) :batch-size Batch size (default 50) :max-attempts Max retry attempts (default 10) :table-name Table name (default :idem_outbox_events)

Returns: A stop function (no-args). Calling it stops the background thread.

Starts the Dispatcher background loop.

Parameters:
  ds        - Database DataSource (used to create the default Postgres store).
  publisher - An implementation of idem.protocol/Publisher.
  opts      - Configuration map (optional):
    :poll-interval-ms    Polling interval (default 1000)
    :batch-size          Batch size (default 50)
    :max-attempts        Max retry attempts (default 10)
    :table-name          Table name (default :idem_outbox_events)

Returns:
  A stop function (no-args). Calling it stops the background thread.
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries